@@ -32,6 +32,9 @@ from spyder.plugins.ipythonconsole import (
 from spyder.plugins.ipythonconsole.comms.kernelcomm import KernelComm
 from spyder.plugins.ipythonconsole.utils.manager import SpyderKernelManager
 from spyder.plugins.ipythonconsole.utils.client import SpyderKernelClient
+from spyder.plugins.ipythonconsole.utils.websocket_client import (
+    SpyderWSKernelClient,
+)
 from spyder.utils.programs import check_version_range
 
 
@@ -99,13 +102,19 @@ class StdThread(QThread):
     def run(self):
         txt = True
         while txt:
-            txt = self._std_buffer.read1()
+            try:
+                txt = self._std_buffer.read1()
+            except ValueError:  # I/O operation on closed file
+                break
+
             if txt:
                 try:
                     txt = txt.decode()
                 except UnicodeDecodeError:
                     txt = str(txt)
                 self.sig_out.emit(txt)
+            else:
+                break  # EOF
 
 
 class KernelHandler(QObject):
@@ -149,14 +158,17 @@ class KernelHandler(QObject):
 
     def __init__(
         self,
-        connection_file,
+        kernel_client,
+        connection_file=None,
         kernel_manager=None,
-        kernel_client=None,
         known_spyder_kernel=False,
         hostname=None,
         sshkey=None,
         password=None,
         ssh_connection=None,
+        websocket_url=None,
+        token=None,
+        aiohttp_session=None,
     ):
         super().__init__()
         # Connection Informations
@@ -164,10 +176,18 @@ class KernelHandler(QObject):
         self.kernel_manager = kernel_manager
         self.kernel_client = kernel_client
         self.known_spyder_kernel = known_spyder_kernel
+
         self.hostname = hostname
         self.sshkey = sshkey
         self.password = password
+
         self.ssh_connection = ssh_connection
+
+        self.websocket_url = websocket_url
+        self.token = token
+
+        self.aiohttp_session = None
+
         self.kernel_error_message = None
         self.connection_state = KernelConnectionState.Connecting
 
@@ -198,11 +218,9 @@ class KernelHandler(QObject):
         self.kernel_comm.open_comm(self.kernel_client)
 
     @property
-    def connection_info(self):
-        """Get connection info."""
-        connection_info = self.kernel_client.get_connection_info()
-        connection_info["key"] = connection_info["key"].decode()
-        return connection_info
+    def is_websocket_client(self):
+        """Return the websocket client."""
+        return isinstance(self.kernel_client, SpyderWSKernelClient)
 
     def connect_(self):
         """Connect to shellwidget."""
@@ -434,7 +452,7 @@ class KernelHandler(QObject):
             json.dump(connection_info, f)
 
         return cls(
-            new_connection_file,
+            connection_file=new_connection_file,
             kernel_client=cls.init_kernel_client(
                 new_connection_file,
                 hostname,
@@ -455,7 +473,7 @@ class KernelHandler(QObject):
     ):
         """Create kernel for given connection file."""
         return cls(
-            connection_file,
+            connection_file=connection_file,
             hostname=hostname,
             sshkey=sshkey,
             password=password,
@@ -468,6 +486,24 @@ class KernelHandler(QObject):
             ),
         )
 
+    @classmethod
+    def from_websocket(
+        cls,
+        websocket_url,
+        token=None,
+        aiohttp_session=None,
+    ):
+        return cls(
+            websocket_url=websocket_url,
+            token=token,
+            aiohttp_session=aiohttp_session,
+            kernel_client=cls.init_ws_kernel_client(
+                websocket_url,
+                token=token,
+                aiohttp_session=aiohttp_session,
+            ),
+        )
+
     @staticmethod
     def init_kernel_client(
         connection_file,
@@ -502,6 +538,21 @@ class KernelHandler(QObject):
 
         return kernel_client
 
+    @staticmethod
+    def init_ws_kernel_client(
+        websocket_url,
+        token=None,
+        username=None,
+        aiohttp_session=None,
+    ):
+        """Create kernel client."""
+        return SpyderWSKernelClient(
+            endpoint=websocket_url,
+            token=token,
+            username=username,
+            aiohttp_session=aiohttp_session,
+        )
+
     def close(self, shutdown_kernel=True, now=False):
         """Close kernel"""
         self.close_comm()
@@ -519,8 +570,8 @@ class KernelHandler(QObject):
             else:
                 shutdown_thread = QThread(None)
                 shutdown_thread.run = self._thread_shutdown_kernel
-                shutdown_thread.start()
                 shutdown_thread.finished.connect(self.after_shutdown)
+                shutdown_thread.start()
                 with self._shutdown_thread_list_lock:
                     self._shutdown_thread_list.append(shutdown_thread)
 
@@ -568,13 +619,20 @@ class KernelHandler(QObject):
         # Copy kernel infos
 
         # Get new kernel_client
-        kernel_client = self.init_kernel_client(
-            self.connection_file,
-            self.hostname,
-            self.sshkey,
-            self.password,
-            self.ssh_connection,
-        )
+        if self.is_websocket_client:
+            kernel_client = self.init_ws_kernel_client(
+                self.websocket_url,
+                token=self.token,
+                aiohttp_session=self.aiohttp_session,
+            )
+        else:
+            kernel_client = self.init_kernel_client(
+                self.connection_file,
+                self.hostname,
+                self.sshkey,
+                self.password,
+                self.ssh_connection,
+            )
 
         return self.__class__(
             connection_file=self.connection_file,
@@ -584,6 +642,9 @@ class KernelHandler(QObject):
             sshkey=self.sshkey,
             password=self.password,
             ssh_connection=self.ssh_connection,
+            websocket_url=self.websocket_url,
+            token=self.token,
+            aiohttp_session=self.aiohttp_session,
             kernel_client=kernel_client,
         )
 
@@ -625,9 +686,14 @@ class KernelHandler(QObject):
 
     def reconnect_kernel(self):
         """Kernel restarted successfully, so reconnect to it."""
-        self.reopen_comm()
-        self.disconnect_std_pipes()
-        self.connect_std_pipes()
+        # Unecessary closing and opening comms as it's already restarted
+        # in `ShellWidget._handle_kernel_restarted` with
+        # `self.kernel_handler.reopen_comm`. But this is required for the
+        # `sig_kernel_is_ready` to be emitted when running our tests.
+        # TODO: Check this logic again
+        self.kernel_comm.close()
+        self.connection_state = KernelConnectionState.Crashed
+        self.kernel_comm.open_comm(self.kernel_client)
 
     def set_time_to_dead(self, time_to_dead):
         """Set time to detect if the kernel is dead in seconds."""
